pub struct NftFlags(/* private fields */);Expand description
A wrapper around NFToken flags that provides efficient helper methods.
Derived Traits
Copy: Efficient for this 2-byte struct, enabling implicit copyingPartialEq, Eq: Enable comparisonsDebug, Clone: Standard traits for development and consistency
Implementations
Sourceimpl NftFlags
impl NftFlags
Sourcepub const fn is_burnable(&self) -> bool
pub const fn is_burnable(&self) -> bool
Checks if the NFToken has the BURNABLE flag set.
If this flag is set, the issuer (or an entity authorized by the issuer) may destroy the token even if they don’t currently hold it.
Sourcepub const fn is_only_xrp(&self) -> bool
pub const fn is_only_xrp(&self) -> bool
Checks if the NFToken has the ONLY_XRP flag set.
If this flag is set, the token may only be bought or sold for XRP.
Sourcepub const fn is_trust_line(&self) -> bool
pub const fn is_trust_line(&self) -> bool
Checks if the NFToken has the TRUST_LINE flag set.
If this flag is set, trust lines are automatically created to hold transfer fees.
Sourcepub const fn is_transferable(&self) -> bool
pub const fn is_transferable(&self) -> bool
Checks if the NFToken has the TRANSFERABLE flag set.
If this flag is set, the token may be transferred to others. If not set, the token can only be transferred back to the issuer.